## Installation

### Installation for users
Install gdsfactory version 7.4.6
```
pip install gdsfactory==7.4.6
```
Install cnmpdk package
```
pip install -i https://test.pypi.org/simple/ cnmpdk
```
### Installation for developers 
```
git clone https://github.com/mario26z/cnm.git
```
Install cnmpdk in dev mode

```
pip install -e .
```

Where `-e` installs the current package `.` in developer mode

### KLayout tech
```
python install_tech.py
```